---
layout: default
---

BackPACK is a library built on top of [PyTorch](https://pytorch.org/)
to make it easy to extract more information from a backward pass.
Some of the things you can compute:
{% include code-samples.html %}

---

**Install with**
```
pip install backpack-for-pytorch 
``` 

---

If you use BackPACK in your research, please cite <float style="float:right"><a href="{{ '/assets/dangel2020backpack.bib' | relative_url }}">download bibtex</a></float>

```
{% include dangel2020backpack.bib %}
```

